.. _interfaces_module:

:mod:`pyramid.interfaces`
----------------------------

.. automodule:: pyramid.interfaces

Event-Related Interfaces
++++++++++++++++++++++++

  .. autointerface:: IApplicationCreated
     :members:

  .. autointerface:: INewRequest
     :members:

  .. autointerface:: IContextFound
     :members:

  .. autointerface:: IBeforeTraversal
     :members:

  .. autointerface:: INewResponse
     :members:

  .. autointerface:: IBeforeRender
     :members:

Other Interfaces
++++++++++++++++

  .. autointerface:: IAuthenticationPolicy
     :members:

  .. autointerface:: IAuthorizationPolicy
     :members:

  .. autointerface:: IExceptionResponse
     :members:

  .. autointerface:: IRoute
     :members:

  .. autointerface:: IRoutePregenerator
     :members:

  .. autointerface:: ICSRFStoragePolicy
     :members:

  .. autointerface:: ISession
     :members:

  .. autointerface:: ISessionFactory
     :members:

  .. autointerface:: IRendererInfo
     :members:

  .. autointerface:: IRendererFactory
     :members:

  .. autointerface:: IRenderer
     :members:

  .. autointerface:: IRequestFactory
     :members:

  .. autointerface:: IResponseFactory
     :members:

  .. autointerface:: IRouter
     :members:

  .. autointerface:: IViewMapperFactory
     :members:

  .. autointerface:: IViewMapper
     :members:

  .. autointerface:: IDict
     :members:

  .. autointerface:: IMultiDict
     :members:

  .. autointerface:: IResponse
     :members:

  .. autointerface:: IIntrospectable
     :members:

  .. autointerface:: IIntrospector
     :members:

  .. autointerface:: IActionInfo
     :members:

  .. autointerface:: IAssetDescriptor
     :members:

  .. autointerface:: IResourceURL
     :members:

  .. autointerface:: ICacheBuster
     :members:

  .. autointerface:: IViewDeriver
     :members:

  .. autointerface:: IViewDeriverInfo
     :members:
